Index: /trunk/src/org/openstreetmap/josm/gui/mappaint/MapImage.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/gui/mappaint/MapImage.java	(revision 6290)
+++ /trunk/src/org/openstreetmap/josm/gui/mappaint/MapImage.java	(revision 6291)
@@ -154,13 +154,13 @@
      * Returns the really displayed node icon for this {@code MapImage}.
      * @param disabled {@code} true to request disabled version, {@code false} for the standard version
      * @return The scaled down version to 16x16 pixels if the image size exceeds 24x24 pixels and no size has been explicitely specified
      * @since 6174
      */
     public Image getDisplayedNodeIcon(boolean disabled) {
-        final int maxSize = 24;
+        final int maxSize = 48;
         final Image image = disabled ? getDisabled() : getImage();
         // Scale down large (.svg) images to 16x16 pixels if no size is explicitely specified
         if ((width  == -1 && image.getWidth(null) > maxSize) 
-         || (height == -1 && image.getHeight(null) > maxSize)) {
+         && (height == -1 && image.getHeight(null) > maxSize)) {
             return ImageProvider.createBoundedImage(image, 16);
         } else {
@@ -154,13 +154,13 @@
      * Returns the really displayed node icon for this {@code MapImage}.
      * @param disabled {@code} true to request disabled version, {@code false} for the standard version
-     * @return The scaled down version to 16x16 pixels if the image size exceeds 24x24 pixels and no size has been explicitely specified
+     * @return The scaled down version to 16x16 pixels if the image height and width exceeds 48 pixels and no size has been explicitely specified
      * @since 6174
      */
